pub struct Cost<B>where
B: BookingTypes,{
pub date: B::Date,
pub per_unit: B::Number,
pub total: B::Number,
pub currency: B::Currency,
pub label: Option<B::Label>,
pub merge: bool,
}Expand description
A cost complete with any fields which were missing from its CostSpec.
In addition to per-unit which is the natural representation, the total
is also exposed, since this may be what the user originally specified in the
beanfile, and ought to be preserved at its original precision.
Fields
date: B::Dateper_unit: B::Numbertotal: B::Numbercurrency: B::Currencylabel: Option<B::Label>merge: boolTrait Implementations
Sourceimpl<B> Display for Cost<B>where
B: BookingTypes,
impl<B> Display for Cost<B>where
B: BookingTypes,
Sourceimpl<B> From<(&<B as BookingTypes>::Currency, &PostingCost<B>)> for Cost<B>where
B: BookingTypes,
impl<B> From<(&<B as BookingTypes>::Currency, &PostingCost<B>)> for Cost<B>where
B: BookingTypes,
Sourcefn from(value: (&B::Currency, &PostingCost<B>)) -> Self
fn from(value: (&B::Currency, &PostingCost<B>)) -> Self
Sourceimpl<B> Hash for Cost<B>where
B: BookingTypes,
impl<B> Hash for Cost<B>where
B: BookingTypes,
Sourceimpl<B> Ord for Cost<B>
impl<B> Ord for Cost<B>
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl<B> PartialEq for Cost<B>where
B: BookingTypes,
impl<B> PartialEq for Cost<B>where
B: BookingTypes,
Sourceimpl<B> PartialOrd for Cost<B>
impl<B> PartialOrd for Cost<B>
impl<B> Eq for Cost<B>where
B: BookingTypes,